import fs from "node:fs/promises";
import path from "node:path";
import process from "node:process";
import memo from "moize/mjs/index.mjs";
import yaml from "yaml";
import { z } from "zod";
const ExtensionConfigurationFileSchema = z.object({
    config: z
        .object({
        slug: z.string().min(1).optional(),
        ui: z
            .object({
            build: z
                .object({ command: z.string().min(1).trim().optional() })
                .optional(),
            dev: z
                .object({ command: z.string().min(1).trim().optional() })
                .optional(),
            surfaces: z.array(z.string().min(1).trim()).optional(),
        })
            .optional(),
    })
        .optional(),
});
const ExtensionConfiguration = z.object({
    slug: z.string().min(1),
    ui: z.object({
        build: z.object({ command: z.string().min(1) }),
        dev: z.object({ command: z.string().min(1) }),
        surfaces: z.array(z.string().min(1)),
    }),
});
const possibleHardDeprecatedFiles = [
    "integration.yaml",
    "integration.yml",
    "netlify-integration.yaml",
    "netlify-integration.yml",
];
const possibleFiles = [
    "extension.yaml",
    "netlify-extension.yaml",
    "extension.yml",
    "netlify-extension.yml",
];
const getConfigurationFile = async (cwd) => {
    for (const filename of possibleFiles.map((filename) => path.resolve(cwd, filename))) {
        try {
            const filepath = path.resolve(cwd, filename);
            const result = await fs.stat(filepath);
            if (result.isFile()) {
                return filepath;
            }
        }
        catch {
            // Continue
        }
    }
    // if we didn't find a new filename above (rename from integration -> extension)
    // check for an old one and throw an error if it exists (to aid in migrating to the new one)
    for (const filename of possibleHardDeprecatedFiles.map((filename) => path.resolve(cwd, filename))) {
        try {
            const filepath = path.resolve(cwd, filename);
            const result = await fs.stat(filepath);
            if (result.isFile()) {
                throw new Error(`Found deprecated extension configuration file ${filename}. This file must be renamed to netlify-extension.yaml`);
            }
        }
        catch {
            // Continue
        }
    }
    return null;
};
export const getExtensionConfiguration = memo.promise(async (cwd) => {
    const filepath = await getConfigurationFile(cwd);
    if (filepath === null) {
        throw new Error(`No extension configuration file found in ${cwd}`);
    }
    try {
        const result = await fs.readFile(filepath, "utf8");
        const { config = {} } = ExtensionConfigurationFileSchema.parse(yaml.parse(result));
        const buildSiteId = (process.env["SITE_ID"] ?? "").trim();
        if (buildSiteId !== "") {
            const metadataRes = await fetch(`https://api.netlifysdk.com/meta/integration-host-site/${buildSiteId}`);
            if (metadataRes.status === 200) {
                const { slug } = (await metadataRes.json());
                config.slug = slug;
            }
        }
        return ExtensionConfiguration.parse({
            ...config,
            ui: {
                ...config.ui,
                build: {
                    command: config.ui?.build?.command ?? "vite build",
                },
                dev: {
                    command: config.ui?.dev?.command ?? "vite dev",
                },
                surfaces: config.ui?.surfaces ?? [],
            },
        });
    }
    catch {
        throw new Error(`Configuration file at ${filepath} is invalid`);
    }
});
//# sourceMappingURL=utils.js.map